@@ -601,7 +601,7 @@ var BaseFileSelectDialog = AdminRESTDialog.extend({
 
 	open: function() {
 		this._super();
-		// Create the upload button after displaying the dialog, because plupload must know the dimensions of the button.
+		// Create the upload button after displaying the dialog
 		this.create_upload_button();
 	},
 
@@ -614,60 +614,50 @@ var BaseFileSelectDialog = AdminRESTDialog.extend({
 	},
 
 	create_upload_button: function() {
-		var button_id = 'upload_file_button';
-		var button_pane_id = 'select-file-buttonpane';
-
 		var button_pane = this.uiDialog.parent().find('.ui-dialog-buttonpane');
 
-		$('<button type="button">'+gettext('Upload a new file')+'</button>')
-			.prependTo(button_pane)
+		var upload_button_pane = $('<div/>').prependTo(button_pane)
+			.attr({
+				'id': 'upload-buttonpane'
+			});
+
+		var upload_button = $('<button type="button">' + gettext('Upload a new file') + '</button>')
+			.appendTo(upload_button_pane)
 			.attr({
 				'class': 'upload',
-				'id': button_id
+				'id': 'upload-file-button'
 			})
 			.button({
 				icons: {
 					primary: 'ui-icon-circle-plus'
 				}
+			})
+			.css({
+				'margin-top': 0,
+				'margin-bottom': 0,
+				'margin-right': 0
 			});
 
-		// Give button pane an id, so we can use it as container for uploader.
-		button_pane.attr('id', button_pane_id);
-
-		var uploader = new plupload.Uploader({
-			runtimes: 'flash,html5',
-			browse_button: button_id,
-			url: this.get_upload_path(),
-			flash_swf_url: STATIC_URL + 'fiber/js/plupload/plupload.flash.swf',
-			multipart_params: {
+		// Valums file uploader
+		var uploader = new qq.FileUploaderBasic({
+			element: upload_button_pane[0],
+			button: upload_button_pane[0], // connecting directly to the jQUery UI upload_button doesn't work
+			action: this.get_upload_path(),
+			params: {
 				'sessionid': $.cookie('sessionid')
 			},
-			container: button_pane_id
-		});
-
-		uploader.bind('Init', function() {
-			// connect 'FilesAdded' event after successful init
-			uploader.bind('FilesAdded', function() {
-				// start upload automatically
-				uploader.start();
-			});
-		});
-
-		uploader.bind('Error', function(up, error) {
-			if (error.code != plupload.INIT_ERROR) {
-				alert(gettext('Upload failed.'));
-			}
-		});
-
-		uploader.init();
-
-		// Bind the 'FileUploaded' event after the init. Otherwise 'total.queued' has a wrong value.
-		uploader.bind('FileUploaded', $.proxy(function() {
-			if (uploader.total.queued === 0) {
-				// all files are uploaded
+			onComplete: $.proxy(function(id, fileName, responseJSON) {
 				this.refresh_grid();
-			}
-		}, this));
+			}, this),
+			debug: false
+		});
+
+		// reset button behavior
+		upload_button_pane.css({
+			'position': 'absolute',
+			'margin-top': 8,
+			'margin-bottom': 8
+		});
 	}
 });
 
@@ -751,7 +741,7 @@ Fiber.ImageSelectDialog = BaseFileSelectDialog.extend({
 			},
 			gridComplete: function() {
 				var num_pages = $("#ui-image-select-grid").getGridParam('lastpage');
-			    if (num_pages > 1) {
+				if (num_pages > 1) {
 					$('#ui-image-select-grid-pager').show();
 				} else {
 					$("#ui-image-select-grid-pager").hide();
@@ -852,7 +842,7 @@ Fiber.FileSelectDialog = BaseFileSelectDialog.extend({
 			},
 			gridComplete: function() {
 				var num_pages = $("#ui-file-select-grid").getGridParam('lastpage');
-			    if (num_pages > 1) {
+				if (num_pages > 1) {
 					$('#ui-file-select-grid-pager').show();
 				} else {
 					$("#ui-file-select-grid-pager").hide();
@@ -1434,6 +1424,7 @@ var adminPage = {
 						}
 
 						// add context menu
+						$link.disableSelection();
 						$link.bind('contextmenu', function(event) {
 							$this = $(this);
 
@@ -1613,83 +1604,87 @@ var adminPage = {
 						}
 					});
 
-					this.admin_content_tree.bind('contextmenu', function(event) {
-						var link = $(event.target).closest('a');
+					var $content_tree_links = this.admin_content_tree.find('li a');
+					$content_tree_links.disableSelection();
+					$content_tree_links.bind('contextmenu', function(event) {
+						var link = $(event.target);
 
 						if (link.length) {
 							event.preventDefault();
 							event.stopPropagation();
 
 							var data = $.parseJSON(link.parent('li').dataset('fiber-data'));
+							if (data) {
 
-							$(document.body).find('.ui-context-menu').remove();
+								$(document.body).find('.ui-context-menu').remove();
 
-							var contextmenu = $('<ul class="ui-context-menu"></ul>');
-
-							contextmenu.append(
-								$('<li><a href="#">'+gettext('Edit')+'</a></li>').click(function() {
-									new ChangeContentItemFormDialog({
-										url: data.url
-									});
-								})
-							);
-
-							contextmenu.append(
-								$('<li><a href="#">'+gettext('Delete')+'</a></li>').click(function() {
-									var confirmationDialog = $('<div></div>').dialog({
-										modal: true,
-										resizable: false,
-										width: 400,
-										position: ['center', 40],
-										buttons: {
-											'Delete': {
-												text: gettext('Delete'),
-												click: function() {
-													$(this).dialog('close');
-
-													busyIndicator.show();
-
-													$.ajax({
-														url: '/api/v1/content_item/' + data.id + '/',
-														type: 'DELETE',
-														data: {},
-														success: function(data) {
-															reloadPage();
-														}
-													});
-												}
-											},
-											'Cancel': {
-												text: gettext('Cancel'),
-												click: function() {
-													$(this).dialog('close');
-												}
-											}
-										}
-									});
-									confirmationDialog.dialog('option', 'title', gettext('Are you sure?'));
-									confirmationDialog.html(gettext('<p>Are you sure you want to delete this item?</p>'));
-								})
-							);
-							if (data.used_on_pages.length >= 1) {
-								var context_submenu_used_on_pages = $('<ul class="ui-context-menu"></ul>');
-
-								$(data.used_on_pages).each(function(index) {
-									context_submenu_used_on_pages.append(
-										$('<li><a href="#">'+data.used_on_pages[index].title+'</a></li>').click(function() {
-											location.href = data.used_on_pages[index].url;
-										})
-									);
-								});
+								var contextmenu = $('<ul class="ui-context-menu"></ul>');
 
 								contextmenu.append(
-									$('<li><a href="#">'+gettext('Used on pages')+'</a></li>').prepend(context_submenu_used_on_pages)
+									$('<li><a href="#">'+gettext('Edit')+'</a></li>').click(function() {
+										new ChangeContentItemFormDialog({
+											url: data.url
+										});
+									})
 								);
-							}
-							contextmenu.flyoutmenu().removeClass('ui-corner-all');
 
-							$(document.body).append(contextmenu);
-							contextmenu.offset({ left: event.pageX, top: event.pageY });
+								contextmenu.append(
+									$('<li><a href="#">'+gettext('Delete')+'</a></li>').click(function() {
+										var confirmationDialog = $('<div></div>').dialog({
+											modal: true,
+											resizable: false,
+											width: 400,
+											position: ['center', 40],
+											buttons: {
+												'Delete': {
+													text: gettext('Delete'),
+													click: function() {
+														$(this).dialog('close');
+
+														busyIndicator.show();
+
+														$.ajax({
+															url: '/api/v1/content_item/' + data.id + '/',
+															type: 'DELETE',
+															data: {},
+															success: function(data) {
+																reloadPage();
+															}
+														});
+													}
+												},
+												'Cancel': {
+													text: gettext('Cancel'),
+													click: function() {
+														$(this).dialog('close');
+													}
+												}
+											}
+										});
+										confirmationDialog.dialog('option', 'title', gettext('Are you sure?'));
+										confirmationDialog.html(gettext('<p>Are you sure you want to delete this item?</p>'));
+									})
+								);
+								if (data.used_on_pages.length >= 1) {
+									var context_submenu_used_on_pages = $('<ul class="ui-context-menu"></ul>');
+
+									$(data.used_on_pages).each(function(index) {
+										context_submenu_used_on_pages.append(
+											$('<li><a href="#">'+data.used_on_pages[index].title+'</a></li>').click(function() {
+												location.href = data.used_on_pages[index].url;
+											})
+										);
+									});
+
+									contextmenu.append(
+										$('<li><a href="#">'+gettext('Used on pages')+'</a></li>').prepend(context_submenu_used_on_pages)
+									);
+								}
+								contextmenu.flyoutmenu().removeClass('ui-corner-all');
+
+								$(document.body).append(contextmenu);
+								contextmenu.offset({ left: event.pageX, top: event.pageY });
+							}
 						}
 					});
 
@@ -2152,6 +2147,7 @@ var FiberItem = Class.extend({
 			$.proxy(this.on_dblclick, this)
 		);
 
+		this.$element.disableSelection();
 		this.$element.bind('contextmenu',
 			$.proxy(this.on_contextmenu, this)
 		);
